@@ -1,11 +1,11 @@
 #  File R/mcmc.diagnostics.ergmm.R in package latentnet, part of the Statnet suite
-#  of packages for network analysis, http://statnet.org .
+#  of packages for network analysis, https://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) at
-#  http://statnet.org/attribution
+#  https://statnet.org/attribution
 #
-#  Copyright 2003-2018 Statnet Commons
+#  Copyright 2003-2020 Statnet Commons
 #######################################################################
 #' Conduct MCMC diagnostics on an ERGMM fit
 #' 
@@ -158,8 +158,8 @@ as.mcmc.list.ergmm<-function(x,burnin=FALSE,
 
   as.mcmc.list.ergmm.par.list(if(burnin) x[["burnin.samples"]][[burnin]] else x[["sample"]],
                               if(is.null(which.vars)) list(lpY=1,
-                                                           beta=1:p,
-                                                           Z=cbind(rep(vertex.i,each=d),rep(1:d,length(vertex.i))),
+                                                           beta=seq_len(p),
+                                                           Z=cbind(rep(vertex.i,each=d),rep(seq_len(d),length(vertex.i))),
                                                            sender=vertex.i,
                                                            receiver=vertex.i,
                                                            sociality=vertex.i,
